@@ -236,9 +236,69 @@ virtualenvwrapper_show_workon_options () {
     #       into the output list.
     # echo seems a little faster than find, even with -depth 3.
     (cd "$WORKON_HOME"; for f in */bin/activate; do echo $f; done) 2>/dev/null | \sed 's|^\./||' | \sed 's|/bin/activate||' | \sort | (unset GREP_OPTIONS; \egrep -v '^\*$')
+    
 #    (cd "$WORKON_HOME"; find -L . -depth 3 -path '*/bin/activate') | sed 's|^\./||' | sed 's|/bin/activate||' | sort
 }
 
+_lsvirtualenv_usage () {
+    echo "lsvirtualenv [-blh]"
+    echo "  -b -- brief mode"
+    echo "  -l -- long mode"
+    echo "  -h -- this help message"
+}
+
+# List virtual environments
+#
+# Usage: lsvirtualenv [-l]
+lsvirtualenv () {
+    typeset args="$(getopt blh "$@")"
+    if [ $? != 0 ]
+    then
+        _lsvirtualenv_usage
+        return 1
+    fi
+    typeset long_mode=true
+    for opt in $args
+    do
+        case "$opt" in
+            -l) long_mode=true;;
+            -b) long_mode=false;;
+            -h) _lsvirtualenv_usage;
+                return 1;;
+        esac
+    done
+
+    if $long_mode
+    then
+        for env_name in $(virtualenvwrapper_show_workon_options)
+        do
+            showvirtualenv "$env_name"
+        done
+    else
+        virtualenvwrapper_show_workon_options
+    fi
+}
+
+# Show details of a virtualenv
+#
+# Usage: showvirtualenv [env]
+showvirtualenv () {
+    typeset env_name="$1"
+    if [ -z "$env_name" ]
+    then
+        if [ -z "$VIRTUAL_ENV" ]
+        then
+            echo "showvirtualenv [env]"
+            return 1
+        fi
+        env_name=$(basename $VIRTUAL_ENV)
+    fi
+
+    echo -n "$env_name"
+    virtualenvwrapper_run_hook "get_env_details" "$env_name"
+    echo
+}
+
 # List or change working virtual environments
 #
 # Usage: workon [environment_name]
@@ -247,7 +307,7 @@ workon () {
 	typeset env_name="$1"
 	if [ "$env_name" = "" ]
     then
-        virtualenvwrapper_show_workon_options
+        lsvirtualenv -b
         return 1
     fi
 
